@@ -1,7 +1,7 @@
 # ABSTRACT: Utilities for Monitoring ElasticSearch
 package App::ElasticSearch::Utilities;
 
-our $VERSION = '3.9'; # VERSION
+our $VERSION = '4.0'; # VERSION
 
 use strict;
 use warnings;
@@ -271,14 +271,7 @@ sub es_request {
 my %_nodes;
 sub es_nodes {
     if(!keys %_nodes) {
-        my $res = es_request('_cat/state', {
-            uri_param => {
-                filter_nodes         => 0,
-                filter_routing_table => 1,
-                filter_indices       => 1,
-                filter_metadata      => 1,
-            },
-        });
+        my $res = es_request('_cluster/state/nodes', {});
         if( !defined $res  ) {
             output({color=>"red"}, "es_nodes(): Unable to locate nodes in status!");
             exit 1;
@@ -611,7 +604,7 @@ App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 3.9
+version 4.0
 
 =head1 SYNOPSIS
 
@@ -654,7 +647,7 @@ distribution.
 
 =head1 FUNCTIONS
 
-=head2 es_global($key)
+=head2 es_globals($key)
 
 Grab the value of the global value from the es-utils.yaml files.
 
