@@ -29,14 +29,7 @@ my $CLUSTER = defined $cres ? $cres->{cluster_name} : 'UNKNOWN';
 
 output({clear=>1,color=>'magenta'}, "Cluster [$CLUSTER] contains $cres->{number_of_nodes} nodes.", '-='x20);
 # Get a list of nodes
-my $nres = es_request('_cluster/state', {
-    uri_param => {
-        filter_routing_table => 1,
-        filter_metadata => 1,
-        filter_blocks => 1,
-        filter_indices => 1,
-    },
-});
+my $nres = es_request('_cluster/state/master_node,nodes', {});
 if(!defined $nres) {
     output({stderr=>1,color=>'red'}, 'Fetching node status failed.');
     exit 1;
@@ -70,7 +63,7 @@ es-nodes.pl - Listing the nodes in a cluster with some details
 
 =head1 VERSION
 
-version 3.9
+version 4.0
 
 =head1 SYNOPSIS
 
@@ -82,42 +75,12 @@ Options:
     --manual            print full manual
     --attibutes         Comma separated list of attributes to display, default is NONE
 
-From App::ElasticSearch::Utilities:
-
-    --local         Use localhost as the elasticsearch host
-    --host          ElasticSearch host to connect to
-    --port          HTTP port for your cluster
-    --noop          Any operations other than GET are disabled
-    --timeout       Timeout to ElasticSearch, default 30
-    --keep-proxy    Do not remove any proxy settings from %ENV
-    --index         Index to run commands against
-    --base          For daily indexes, reference only those starting with "logstash"
-                     (same as --pattern logstash-* or logstash-DATE)
-    --datesep       Date separator, default '.' also (--date-separator)
-    --pattern       Use a pattern to operate on the indexes
-    --days          If using a pattern or base, how many days back to go, default: all
-
-=head2 ARGUMENT GLOBALS
-
-Some options may be specified in the B</etc/es-utils.yaml> or B<$HOME/.es-utils.yaml> file:
-
-    ---
-    host: esproxy.example.com
-    port: 80
-    timeout: 10
-
 From CLI::Helpers:
 
-    --data-file         Path to a file to write lines tagged with 'data => 1'
     --color             Boolean, enable/disable color, default use git settings
-    --verbose           Incremental, increase verbosity (Alias is -v)
+    --verbose           Incremental, increase verbosity
     --debug             Show developer output
-    --debug-class       Show debug messages originating from a specific package, default: main
     --quiet             Show no output (for cron)
-    --syslog            Generate messages to syslog as well
-    --syslog-facility   Default "local0"
-    --syslog-tag        The program name, default is the script name
-    --syslog-debug      Enable debug messages to syslog if in use, default false
 
 =head1 DESCRIPTION
 
