@@ -72,14 +72,7 @@ exit 0;
 # Query functions
 sub handle_health {
     my $stats = es_request('_cluster/health');
-    my $state = es_request('_cluster/state', {
-        uri_param => {
-            filter_routing_table => 1,
-            filter_metadata => 1,
-            filter_blocks => 1,
-            filter_index => 1,
-        },
-    });
+    my $state = es_request('_cluster/state/master_node,nodes', {});
 
     output({clear=>1,color=>"cyan"}, "Cluster Health Check", "-="x20);
     if( defined $state && exists $state->{master_node} && exists $state->{nodes}{$state->{master_node}}) {
@@ -222,7 +215,7 @@ es-status.pl - Simple ElaticSearch Status Checks
 
 =head1 VERSION
 
-version 3.9
+version 4.0
 
 =head1 SYNOPSIS
 
@@ -240,27 +233,12 @@ Query Modes:
 
     --all               Run all handlers!
 
-=head2 ARGUMENT GLOBALS
-
-Some options may be specified in the B</etc/es-utils.yaml> or B<$HOME/.es-utils.yaml> file:
-
-    ---
-    host: esproxy.example.com
-    port: 80
-    timeout: 10
-
 From CLI::Helpers:
 
-    --data-file         Path to a file to write lines tagged with 'data => 1'
     --color             Boolean, enable/disable color, default use git settings
-    --verbose           Incremental, increase verbosity (Alias is -v)
+    --verbose           Incremental, increase verbosity
     --debug             Show developer output
-    --debug-class       Show debug messages originating from a specific package, default: main
     --quiet             Show no output (for cron)
-    --syslog            Generate messages to syslog as well
-    --syslog-facility   Default "local0"
-    --syslog-tag        The program name, default is the script name
-    --syslog-debug      Enable debug messages to syslog if in use, default false
 
 =head1 DESCRIPTION
 
